@@ -10,7 +10,7 @@ from velbus.constants import (
     MAXIMUM_MESSAGE_SIZE,
     RTR,
 )
-from velbus.util import checksum
+from velbus.util import checksum, VelbusException
 from velbus.messages.module_type import ModuleTypeMessage
 from velbus.messages.module_subtype import ModuleSubTypeMessage
 from velbus.messages.module_type_request import ModuleTypeRequestMessage
@@ -51,6 +51,9 @@ class VelbusParser(object):
             result = result and self.buffer[0] == START_BYTE
             if not result:
                 self.logger.warning("Start byte not recognized")
+            if self.buffer[1] == START_BYTE:
+                self.buffer = self.buffer[1:]
+                self.logger.debug('Duplicate start byte found, discarding first one')
             result = result and (self.buffer[1] in PRIORITY)
             if not result:
                 self.logger.warning("Priority not recognized")
@@ -101,6 +104,8 @@ class VelbusParser(object):
             message = self.parse(next_packet)
             if message is not None:
                 self.controller.new_binary_message(message)
+        else:
+            raise VelbusException('No valid next packet found')
 
     def extract_packet(self):
         """
